==> tecfy_core_package-0.1.6.tar.gz: lib/views/components/dashboard/dashboard_statistics.component.dart <==
part of tecfy_core_client_package;

class DashboardStatisticsComponenet extends StatefulWidget {
  final DashboardItemBase type;
  DashboardStatisticsComponenet(this.type);
  @override
  _DashboardStatisticsComponenetState createState() => _DashboardStatisticsComponenetState();
}

class _DashboardStatisticsComponenetState extends State<DashboardStatisticsComponenet> {
  
  onItemTab(type)async{
    if(type.onClick == null || type.onClick.isEmpty)return;
    if(type.onClick.startsWith('EntityList:')){
      AppNavigator.navigateTo(context, ()=>EntityListPage(type.onClick.replaceAll('EntityList:', '')));
      return;
    }
    if(type.onClick.startsWith('Report:')){
      var result = await ApiService.httpGetDynamic('Report/GetList');          
      var reportName = type.onClick.replaceAll('Report:', '');
      AppNavigator.navigateTo(context, ()=>ReportDetailPage(result.data.firstWhere((s)=>s['dbName'] ==reportName),[]));
      return;
    }
  }

  Future<dynamic> getData() async{
    var type = widget.type;
    if(type.value != null ) return type.value;
    if(type.value == -1) return null;
    type.value = -1;
    var result = await ApiService.httpGetDynamic('Dashboard/GetData/${type.dbName}');
    //print(result.toString());
    if(result.success){
      //return result.data;
      type.value =result.data;
    }else{
      type.value ='0';
    }
    setState((){});
    return type.value;
  }

  getWidth(){
    var fullwidth = LayoutService.getWidth(context);
    if(LayoutService.isMobile(context)){
      return fullwidth -20;
    }
    fullwidth -= 200;
    if(fullwidth > 1000) fullwidth =1000;
    if(fullwidth < 1000)
      return fullwidth /2;
    return fullwidth /4;
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      //constraints: BoxConstraints(minWidth: 250),
      width: getWidth(),
      child:  GestureDetector(
      onTap: ()=>onItemTab(widget.type),
      child: Card(
      elevation: 2,
      margin: EdgeInsets.all(10),
      child: Column(children: <Widget>[
        SizedBox(height:10),
        Text(widget.type.title ?? ''),
        SizedBox(height:10),
        FutureBuilder<dynamic>(
          future: getData(),
          builder:(c,snap)=> Text(widget.type.value != null ? widget.type.value.toString().trim().replaceAll('SAR', LocalConfigService.isArabic ? 'ريال' : 'SAR'  ) ?? '-' : '${AppLocale.translate(c,'Loading')}..'),
        ),
        SizedBox(height:10),
      ],) 

    )));
  }
}

==> tecfy_core_package-0.1.17.tar.gz: lib/views/components/dashboard/dashboard_statistics.component.dart <==
part of tecfy_core_client_package;

class DashboardStatisticsComponenet extends StatefulWidget {
  final DashboardItemBase type;
  DashboardStatisticsComponenet(this.type);
  @override
  _DashboardStatisticsComponenetState createState() => _DashboardStatisticsComponenetState();
}

class _DashboardStatisticsComponenetState extends State<DashboardStatisticsComponenet> {
  
  onItemTab(type)async{
    if(type.onClick == null || type.onClick.isEmpty)return;
    if(type.onClick.startsWith('EntityList:')){
      AppNavigator.navigateTo(context, ()=>EntityListPage(type.onClick.replaceAll('EntityList:', '')));
      return;
    }
    if(type.onClick.startsWith('Report:')){
      var result = await ApiService.httpGetDynamic('Report/GetList');          
      var reportName = type.onClick.replaceAll('Report:', '');
      AppNavigator.navigateTo(context, ()=>ReportDetailPage(result.data.firstWhere((s)=>s['dbName'] ==reportName),[]));
      return;
    }
  }

  Future<dynamic> getData() async{
    var type = widget.type;
    if(type.value != null ) return type.value;
    if(type.value == -1) return null;
    type.value = -1;
    var result = await ApiService.httpGetDynamic('Dashboard/GetData/${type.dbName}');
    //print(result.toString());
    if(result.success){
      //return result.data;
      type.value =result.data;
    }else{
      type.value ='0';
    }
    setState((){});
    return type.value;
  }

  getWidth(){
    var fullwidth = LayoutService.getWidth(context);
    if(LayoutService.isMobile(context)){
      return fullwidth -20;
    }
    fullwidth -= (ThemeService.menuWidth + 40);
    if(fullwidth > ThemeService.containerWidth) fullwidth = ThemeService.containerWidth - 40;
    if(fullwidth < 600)
      return fullwidth /2;
    return fullwidth /4;
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      //constraints: BoxConstraints(minWidth: 250),
      width: getWidth(),
      child:  GestureDetector(
      onTap: ()=>onItemTab(widget.type),
      child: Card(
      elevation: 2,
      margin: EdgeInsets.all(10),
      child: Column(children: <Widget>[
        SizedBox(height:10),
        Text(widget.type.title ?? ''),
        SizedBox(height:10),
        FutureBuilder<dynamic>(
          future: getData(),
          builder:(c,snap)=> Text(widget.type.value != null ? widget.type.value.toString().trim().replaceAll('SAR', LocalConfigService.isArabic ? 'ريال' : 'SAR'  ) ?? '-' : '${AppLocale.translate(c,'Loading')}..'),
        ),
        SizedBox(height:10),
      ],) 

    )));
  }
}
